package com.supermap.dataconversion;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.LinearLayout.LayoutParams;
import android.widget.PopupWindow;
import android.widget.Toast;

import com.supermap.data.DataConversion;
import com.supermap.data.Dataset;
import com.supermap.data.DatasetVector;
import com.supermap.data.Datasource;
import com.supermap.mapping.MapControl;

public class ExportData extends PopupWindow implements OnClickListener {
	private MapControl mMapControl = null;
	private LayoutInflater mInflater = null;
	private View mContentView = null;
	private Datasource udbDatasource = null;
	private Context context = null;

	/**
	 * Constructor
	 * 
	 * @param mapcontrol
	 */
	public ExportData(MapControl mapcontrol,Context context) {
		mMapControl = mapcontrol;
		this.context = context;
		mInflater = LayoutInflater.from(mMapControl.getContext());
		loadView();
		setContentView(mContentView);
		setWidth(LayoutParams.WRAP_CONTENT);
		setHeight(LayoutParams.WRAP_CONTENT);
		udbDatasource = mMapControl.getMap().getWorkspace().getDatasources()
				.get("World");
	}

	/**
	 * Initialize interface control
	 */
	private void loadView() {
		mContentView = mInflater.inflate(R.layout.dataoperation, null);
		mContentView.findViewById(R.id.btn_dwg).setOnClickListener(this);
		mContentView.findViewById(R.id.btn_dxf).setOnClickListener(this);
		mContentView.findViewById(R.id.btn_mif).setOnClickListener(this);
		mContentView.findViewById(R.id.btn_shp).setOnClickListener(this);
		mContentView.findViewById(R.id.btn_tif).setOnClickListener(this);
	}

	/**
	 * Display the drawing toolbar
	 */
	public void showExport(View anchorView) {
		showAsDropDown(anchorView, 0, -2);
	}

	/**
	 * Close the toolbar
	 */
	public void dismiss() {
		super.dismiss();
	}

	// Import the data
	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.btn_dwg:
			exportDwg(context);
			break;
		case R.id.btn_dxf:
			exportDxf(context);
			break;
		case R.id.btn_mif:
			exportMif(context);
			break;
		case R.id.btn_shp:
			exportShp(context);
			break;
		case R.id.btn_tif:
			exportTif(context);
			break;

		default:
			break;
		}

	}

	/**
	 * Export the tif data
	 */
	private void exportTif(Context context) {
		// Get the dataset
		Dataset tifDataset = udbDatasource.getDatasets()
				.get("tifImport");
		if (tifDataset == null) {
			Toast.makeText(context, "Please import the data", Toast.LENGTH_SHORT).show();
			return;
		}
		try {
			// Export the dataset to the tif format
			boolean tifExport = DataConversion.exportTIF(MainActivity.exportTIF,
					tifDataset);
			if (tifExport == true) {
				Toast.makeText(context, "Export the tif file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to export the tif file", Toast.LENGTH_SHORT)
						.show();
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Export the shp data
	 */
	private void exportShp(Context context) {
		// Get the dataset
		Dataset shpDataset =  udbDatasource.getDatasets()
				.get("shpImport");
		if (shpDataset == null) {
			Toast.makeText(context, "Please import the data", Toast.LENGTH_SHORT).show();
			return;
		}
		try {
			// Export the dataset to the shp format
			boolean shpExport = DataConversion.exportSHP(MainActivity.exportSHP,
					shpDataset);
			if (shpExport == true) {
				Toast.makeText(context, "Export the shp file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to export the shp file", Toast.LENGTH_SHORT)
						.show();
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Export the mif data
	 */
	private void exportMif(Context context) {
		// Get the dataset
		Dataset mifDataset =  udbDatasource.getDatasets()
				.get("mifImportR");
		if (mifDataset == null) {
			Toast.makeText(context, "Please import the data", Toast.LENGTH_SHORT).show();
			return;
		}
		try {
			// Export the dataset to the CAD format
			boolean mifExport = DataConversion.exportMIF(MainActivity.exportMIF,
					mifDataset);
			if (mifExport == true) {
				Toast.makeText(context, "Export the mif file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to export the mif file", Toast.LENGTH_SHORT)
						.show();
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Export the dxf data
	 */
	private void exportDxf(Context context) {
		// Get the dataset
		Dataset dxfDataset = udbDatasource.getDatasets()
				.get("dxfImport");
		if (dxfDataset == null) {
			Toast.makeText(context, "Please import the data", Toast.LENGTH_SHORT).show();
			return;
		}
		try {
			// Export the dataset to the CAD format
			boolean dxfExport = DataConversion.exportDXF(MainActivity.exportDXF,
					dxfDataset);
			if (dxfExport == true) {
				Toast.makeText(context, "Export the dxf file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to export the dxf file", Toast.LENGTH_SHORT)
						.show();
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Export the dwg data
	 */
	private void exportDwg(Context context) {
		// Get the dataset
		Dataset dwgDataset = udbDatasource.getDatasets()
				.get("dwgImport");
		if (dwgDataset == null) {
			Toast.makeText(context, "Please import the data", Toast.LENGTH_SHORT).show();
			return;
		}
		try {
			// Export the dataset to the dwg format
			boolean dwgExport = DataConversion.exportDWG(MainActivity.exportDWG,
					dwgDataset);
			if (dwgExport == true) {
				Toast.makeText(context, "Export the dwg file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to export the dwg file", Toast.LENGTH_SHORT)
						.show();
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

}
