package com.supermap.dataconversion;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.LinearLayout.LayoutParams;
import android.widget.PopupWindow;
import android.widget.Toast;

import com.supermap.data.DataConversion;
import com.supermap.data.Dataset;
import com.supermap.data.DatasetVector;
import com.supermap.data.Datasource;
import com.supermap.mapping.Layer;
import com.supermap.mapping.MapControl;

public class ImportData extends PopupWindow implements OnClickListener {
	private MapControl mMapControl = null;
	private LayoutInflater mInflater = null;
	private View mContentView = null;
	private Datasource udbDatasource = null;
	private Dataset dataset = null;
	private Layer mLayer = null;
	private Context context = null;
	/**
	 * Constructor
	 * 
	 * @param mapcontrol
	 */
	public ImportData(MapControl mapcontrol,Context context) {
		mMapControl = mapcontrol;
		this.context = context;
		mInflater = LayoutInflater.from(mMapControl.getContext());
		loadView();
		setContentView(mContentView);
		setWidth(LayoutParams.WRAP_CONTENT);
		setHeight(LayoutParams.WRAP_CONTENT);
		udbDatasource = mMapControl.getMap().getWorkspace().getDatasources()
				.get("World");
	}

	/**
	 * Initialize interface control
	 */
	private void loadView() {
		mContentView = mInflater.inflate(R.layout.dataoperation, null);
		mContentView.findViewById(R.id.btn_dwg).setOnClickListener(this);
		mContentView.findViewById(R.id.btn_dxf).setOnClickListener(this);
		mContentView.findViewById(R.id.btn_mif).setOnClickListener(this);
		mContentView.findViewById(R.id.btn_shp).setOnClickListener(this);
		mContentView.findViewById(R.id.btn_tif).setOnClickListener(this);
	}

	/**
	 * Display the drawing toolbar
	 */
	public void showImport(View anchorView) {
		showAsDropDown(anchorView, 0, -2);
	}

	/**
	 * Close the toolbar
	 */

	public void dismiss() {
		super.dismiss();
	}

	// Import the data
	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.btn_dwg:
			importDwg(context);
			break;
		case R.id.btn_dxf:
			importDxf(context);
			break;
		case R.id.btn_mif:
			importMif(context);
			break;
		case R.id.btn_shp:
			importShp(context);
			break;
		case R.id.btn_tif:
			importTif(context);
			break;

		default:
			break;
		}

	}

	/**
	 * Export the tif data
	 */
	private void importTif(Context context) {
		removeLayer();
		mMapControl.getMap().refresh();
		try {
			boolean d = udbDatasource.getDatasets().delete("tifImport");
			// Add the CAD data to the dataset
			boolean tif = DataConversion.importTIF(MainActivity.importTIF,
					udbDatasource);

			if (tif == true) {
				dataset = udbDatasource.getDatasets().get(
						"tifImport");
				addMap();
				Toast.makeText(context, "Import the tif file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to import the tif file", Toast.LENGTH_SHORT)
						.show();
			}

		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	/**
	 * Import the shp data
	 */
	private void importShp(Context context) {
		removeLayer();
		mMapControl.getMap().refresh();
		try {
			boolean d = udbDatasource.getDatasets().delete("shpImport");
			// Add the CAD data to the dataset
			boolean shp = DataConversion.importSHP(MainActivity.importSHP,
					udbDatasource);

			if (shp == true) {
				dataset = udbDatasource.getDatasets().get(
						"shpImport");
				addMap();
				Toast.makeText(context, "Import the shp file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to import the shp file", Toast.LENGTH_SHORT)
						.show();
			}

		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Import the mif data
	 */
	private void importMif(Context context) {
		removeLayer();
		mMapControl.getMap().refresh();
		try {
			boolean d = udbDatasource.getDatasets().delete("mifImportR");
			// Add the mif data to the dataset
			boolean mif = DataConversion.importMIF(MainActivity.importMIF,
					udbDatasource);

			if (mif == true) {
				dataset =  udbDatasource.getDatasets().get(
						"mifImportR");
				addMap();
				Toast.makeText(context, "Import the mif file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to import the mif file", Toast.LENGTH_SHORT)
						.show();
			}

		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Import the dxf data
	 */
	private void importDxf(Context context) {
		removeLayer();
		mMapControl.getMap().refresh();
		try {
			boolean d = udbDatasource.getDatasets().delete("dxfImport");
			// Add the CAD data to the dataset
			boolean dxf = DataConversion.importDXF(MainActivity.importDXF,
					udbDatasource, true);

			if (dxf == true) {
				dataset = udbDatasource.getDatasets().get(
						"dxfImport");
				addMap();
				Toast.makeText(context, "Import the dxf file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to import the dxf file", Toast.LENGTH_SHORT)
						.show();
			}

		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Import the dwg data
	 */
	private void importDwg(Context context) {
		removeLayer();
		mMapControl.getMap().refresh();
		try {
			boolean d = udbDatasource.getDatasets().delete("dwgImport");
			// Add the CAD data to the dataset
			boolean dwg = DataConversion.importDWG(MainActivity.importDWG,
					udbDatasource, true);
			if (dwg == true) {
				dataset =  udbDatasource.getDatasets().get(
						"dwgImport");
				addMap();
				Toast.makeText(context, "Import the dwg file successfully", Toast.LENGTH_SHORT)
						.show();
			} else {
				Toast.makeText(context, "Failed to import the dwg file", Toast.LENGTH_SHORT)
						.show();
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Add to the map
	 */
	private void addMap() {
		mLayer = mMapControl.getMap().getLayers().add(dataset, true);
		mLayer.setVisible(true);
		mLayer.setEditable(true);
		mMapControl.getMap().viewEntire();
		mMapControl.getMap().refresh();

	}

	/**
	 * Remove the layer
	 */
	private void removeLayer() {
		mMapControl.getMap().close();  // Close map, and then add the layer.
//		mMapControl.getMap().getLayers().remove("dwgImport@World");
//		mMapControl.getMap().getLayers().remove("dxfImport@World");
//		mMapControl.getMap().getLayers().remove("tifImport@World");
//		mMapControl.getMap().getLayers().remove("mifImport@World");
//		mMapControl.getMap().getLayers().remove("shpImport@World");
	}

}
