package com.supermap.dataconversion;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

import com.supermap.data.Environment;
import com.supermap.data.Workspace;
import com.supermap.data.WorkspaceConnectionInfo;
import com.supermap.data.WorkspaceType;
import com.supermap.mapping.MapControl;
import com.supermap.mapping.MapView;

/**
 * <p>
 * Title: Data import and export
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------Statement----------------------------
 * This is for SuperMap iMobile for Android Sample Code 
 * Copyright: SuperMap Software Co., Ltd.
 * ----------------------------------------------------------------
 * ----------------------------SuperMap iMobile
 * Demo---------------------------
 * 
 * 1. Introduction: Data is imported into the map dataset. Export the dataset to data format.
 *  2. Demo data:
 * Data directory: "SampleData/DataConversion/" 
 * Map data: "World.smwu", "World.udb","World.udd"
 * Lincese: "/SuperMap/License/" 
 * 3. Members: 
 * DataConversion.importDWG(); Method
 * DataConversion.importDXF(); Method 
 * DataConversion.importMIF(); Method 
 * DataConversion.importTIF(); Method 
 * DataConversion.importSHP(); Method 
 * DataConversion.exportDWG(); Method
 * DataConversion.exportDXF(); Method
 * DataConversion.exportMIF(); Method
 * DataConversion.exportSHP(); Method
 * DataConversion.exportTIF(); Method
 * 
 * 4. Function display (1)Data type import; (2)Data is exported to the dataset. --------------------------------------------
 * ----------------------------------
 * ============================================================================>
 * </p>
 * 
 * <p>
 * Company: SuperMap Software Co., Ltd.
 * </p>
 * 
 */
public class MainActivity extends Activity implements OnClickListener {

	private Workspace mWorkspace = null;
	private MapView mMapView = null;
	private MapControl mMapControl = null;
	private Button btnImport = null;
	private Button btnExport = null;
	private static String sdCard = android.os.Environment
			.getExternalStorageDirectory().getAbsolutePath();
	public static String importDWG = sdCard
			+ "/SampleData/DataConversion/dwgImport.dwg";
	public static String importDXF = sdCard
			+ "/SampleData/DataConversion/dxfImport.dxf";
	public static String importTIF = sdCard
			+ "/SampleData/DataConversion/tifImport.tif";
	public static String importMIF = sdCard
			+ "/SampleData/DataConversion/mifImport.mif";
	public static String importSHP = sdCard
			+ "/SampleData/DataConversion/shpImport.shp";
	public static String exportDWG = sdCard
			+ "/SampleData/DataConversion/dwgExport.dwg";
	public static String exportDXF = sdCard
			+ "/SampleData/DataConversion/dxfExport.dxf";
	public static String exportTIF = sdCard
			+ "/SampleData/DataConversion/tifExport.tif";
	public static String exportMIF = sdCard
			+ "/SampleData/DataConversion/mifExport.mif";
	public static String exportSHP = sdCard
			+ "/SampleData/DataConversion/shpExport.shp";

	private ImportData mImportData = null;
	private ExportData mExportData = null;
	//accepting the focus
	private View anchorView = null;
	private Button btnZoomIn;
	private Button btnZoomOut;
	private Button btnViewEntire;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		// Set the license path
		Environment.setLicensePath(sdCard + "/SuperMap/license/");
		// Initialize the environment
		Environment.initialization(this);
		Environment.setOpenGLMode(false);
		setContentView(R.layout.activity_main);
		initView();
		openMap();
		mImportData = new ImportData(mMapControl, MainActivity.this);
		mExportData = new ExportData(mMapControl, MainActivity.this);
	}

	/**
	 * Initialize the control
	 */
	private void initView() {
		MapView mapView = (MapView) findViewById(R.id.mapView);
		mMapControl = mapView.getMapControl();
		btnImport = (Button) findViewById(R.id.btn_import);
		btnExport = (Button) findViewById(R.id.btn_export);
		btnZoomIn = (Button) findViewById(R.id.btnZoomIn);
		btnZoomOut = (Button) findViewById(R.id.btnZoomOut);
		btnViewEntire = (Button) findViewById(R.id.btnViewEntire);
		btnImport.setOnClickListener(this);
		btnExport.setOnClickListener(this);
		btnZoomIn.setOnClickListener(this);
		btnZoomOut.setOnClickListener(this);
		btnViewEntire.setOnClickListener(this);
		anchorView = findViewById(R.id.btn_import);

	}

	/**
	 * Open the map
	 */
	private void openMap() {
		mWorkspace = new Workspace();
		WorkspaceConnectionInfo info = new WorkspaceConnectionInfo();
		info.setServer(sdCard + "/SampleData/DataConversion/World.smwu");
		info.setType(WorkspaceType.SMWU);
		mWorkspace.open(info);
		// The map display controls are associated to the workspace
		mMapView = (MapView) findViewById(R.id.mapView);
		mMapControl = mMapView.getMapControl();
		mMapControl.getMap().setWorkspace(mWorkspace);
	}

	/**
	 * Select the button
	 */
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.btn_import:
			if (mImportData.isShowing()) {
				mImportData.dismiss();
			} else {
				mImportData.showImport(anchorView);
			}
			break;
		case R.id.btn_export:
			if (mExportData.isShowing()) {
				mExportData.dismiss();
			} else {
				mExportData.showExport(anchorView);
			}
			break;
		case R.id.btnZoomIn:
			mMapControl.getMap().zoom(2);
			mMapControl.getMap().refresh();
			break;
		case R.id.btnZoomOut:
			mMapControl.getMap().zoom(0.5);
			mMapControl.getMap().refresh();
			break;
		case R.id.btnViewEntire:
			mMapControl.getMap().viewEntire();
			mMapControl.getMap().refresh();
			break;
		default:
			break;
		}

	}

}
